==> kubernetes-model-3.0.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/CustomResourceDefinitionSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CustomResourceDefinitionSpecBuilder extends CustomResourceDefinitionSpecFluentImpl<CustomResourceDefinitionSpecBuilder> implements VisitableBuilder<CustomResourceDefinitionSpec,CustomResourceDefinitionSpecBuilder>{

    CustomResourceDefinitionSpecFluent<?> fluent;
    Boolean validationEnabled;

    public CustomResourceDefinitionSpecBuilder(){
            this(true);
    }
    public CustomResourceDefinitionSpecBuilder(Boolean validationEnabled){
            this(new CustomResourceDefinitionSpec(), validationEnabled);
    }
    public CustomResourceDefinitionSpecBuilder(CustomResourceDefinitionSpecFluent<?> fluent){
            this(fluent, true);
    }
    public CustomResourceDefinitionSpecBuilder(CustomResourceDefinitionSpecFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new CustomResourceDefinitionSpec(), validationEnabled);
    }
    public CustomResourceDefinitionSpecBuilder(CustomResourceDefinitionSpecFluent<?> fluent,CustomResourceDefinitionSpec instance){
            this(fluent, instance, true);
    }
    public CustomResourceDefinitionSpecBuilder(CustomResourceDefinitionSpecFluent<?> fluent,CustomResourceDefinitionSpec instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withGroup(instance.getGroup()); 
            fluent.withNames(instance.getNames()); 
            fluent.withScope(instance.getScope()); 
            fluent.withValidation(instance.getValidation()); 
            fluent.withVersion(instance.getVersion()); 
            this.validationEnabled = validationEnabled; 
    }
    public CustomResourceDefinitionSpecBuilder(CustomResourceDefinitionSpec instance){
            this(instance,true);
    }
    public CustomResourceDefinitionSpecBuilder(CustomResourceDefinitionSpec instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withGroup(instance.getGroup()); 
            this.withNames(instance.getNames()); 
            this.withScope(instance.getScope()); 
            this.withValidation(instance.getValidation()); 
            this.withVersion(instance.getVersion()); 
            this.validationEnabled = validationEnabled; 
    }

    public CustomResourceDefinitionSpec build(){
            CustomResourceDefinitionSpec buildable = new CustomResourceDefinitionSpec(fluent.getGroup(),fluent.getNames(),fluent.getScope(),fluent.getValidation(),fluent.getVersion());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            CustomResourceDefinitionSpecBuilder that = (CustomResourceDefinitionSpecBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-4.1.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/CustomResourceDefinitionSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
import javax.validation.Validator;

public class CustomResourceDefinitionSpecBuilder extends CustomResourceDefinitionSpecFluentImpl<CustomResourceDefinitionSpecBuilder> implements VisitableBuilder<CustomResourceDefinitionSpec,CustomResourceDefinitionSpecBuilder>{

    CustomResourceDefinitionSpecFluent<?> fluent;
    Boolean validationEnabled;
    Validator validator;

    public CustomResourceDefinitionSpecBuilder(){
            this(true);
    }
    public CustomResourceDefinitionSpecBuilder(Boolean validationEnabled){
            this(new CustomResourceDefinitionSpec(), validationEnabled);
    }
    public CustomResourceDefinitionSpecBuilder(CustomResourceDefinitionSpecFluent<?> fluent){
            this(fluent, true);
    }
    public CustomResourceDefinitionSpecBuilder(CustomResourceDefinitionSpecFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new CustomResourceDefinitionSpec(), validationEnabled);
    }
    public CustomResourceDefinitionSpecBuilder(CustomResourceDefinitionSpecFluent<?> fluent,CustomResourceDefinitionSpec instance){
            this(fluent, instance, true);
    }
    public CustomResourceDefinitionSpecBuilder(CustomResourceDefinitionSpecFluent<?> fluent,CustomResourceDefinitionSpec instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withGroup(instance.getGroup()); 
            fluent.withNames(instance.getNames()); 
            fluent.withScope(instance.getScope()); 
            fluent.withValidation(instance.getValidation()); 
            fluent.withVersion(instance.getVersion()); 
            this.validationEnabled = validationEnabled; 
    }
    public CustomResourceDefinitionSpecBuilder(CustomResourceDefinitionSpec instance){
            this(instance,true);
    }
    public CustomResourceDefinitionSpecBuilder(CustomResourceDefinitionSpec instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withGroup(instance.getGroup()); 
            this.withNames(instance.getNames()); 
            this.withScope(instance.getScope()); 
            this.withValidation(instance.getValidation()); 
            this.withVersion(instance.getVersion()); 
            this.validationEnabled = validationEnabled; 
    }
    public CustomResourceDefinitionSpecBuilder(Validator validator){
            this(new CustomResourceDefinitionSpec(), true);
    }
    public CustomResourceDefinitionSpecBuilder(CustomResourceDefinitionSpecFluent<?> fluent,CustomResourceDefinitionSpec instance,Validator validator){
            this.fluent = fluent; 
            fluent.withGroup(instance.getGroup()); 
            fluent.withNames(instance.getNames()); 
            fluent.withScope(instance.getScope()); 
            fluent.withValidation(instance.getValidation()); 
            fluent.withVersion(instance.getVersion()); 
            this.validator = validator;
            this.validationEnabled = validator != null; 
    }
    public CustomResourceDefinitionSpecBuilder(CustomResourceDefinitionSpec instance,Validator validator){
            this.fluent = this; 
            this.withGroup(instance.getGroup()); 
            this.withNames(instance.getNames()); 
            this.withScope(instance.getScope()); 
            this.withValidation(instance.getValidation()); 
            this.withVersion(instance.getVersion()); 
            this.validator = validator; 
            this.validationEnabled = validator != null; 
    }

    public CustomResourceDefinitionSpec build(){
            CustomResourceDefinitionSpec buildable = new CustomResourceDefinitionSpec(fluent.getGroup(),fluent.getNames(),fluent.getScope(),fluent.getValidation(),fluent.getVersion());
            if (validationEnabled) {io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable, validator);}
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            CustomResourceDefinitionSpecBuilder that = (CustomResourceDefinitionSpecBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
